@@ -626,3 +626,24 @@ def get_best_nearest_resolution(preferred_res, support_res, aspect_only=False):
     keyfunc = lambda x,y,g, dasp: g -g * dasp
     bestRes = max(support_res_int, key=lambda x:keyfunc(*x) )
     return "%sx%s" % bestRes[0:2]
+
+def get_traceback_caller(e1, e2, frame):
+    """
+    Получить модуль и строку вызвавшую эту функции с ошибкой
+    """
+    while frame.tb_next:
+        frame = frame.tb_next
+
+    module, part = os.path.split(frame.tb_frame.f_back.f_code.co_filename)
+    if part.endswith('.py'):
+        part = part[:-3]
+    fallbackmod = part
+    modname = [part]
+    while module and module != '/' and not module.endswith('site-packages'):
+        module, part = os.path.split(module)
+        modname.insert(0, part)
+    if module.endswith('site-packages'):
+        modname = ".".join(modname)
+    else:
+        modname = fallbackmod
+    return modname, frame.tb_frame.f_back.f_lineno
